using System;
using System.Collections.Generic;

using Server;

namespace Server.Items
{
	public class PlateSet : ItemSet
	{
		private SetPart[] m_Parts = new SetPart[]
		{
			new SetPart(typeof(PlateHelm), "Plate Helm"),
			new SetPart(typeof(PlateChest), "Plate Chestguard"),
			new SetPart(typeof(PlateArms), "Plate Armguards"),
			new SetPart(typeof(PlateGorget), "Plate Gorget"),
			new SetPart(typeof(PlateLegs), "Plate Leggings"),
			new SetPart(typeof(PlateGloves), "Plate Gauntlets"),
		};

		private SetBonus[] m_Bonuses = new SetBonus[]
		{
			new PlateSetBonus(2),
			new PlateSetBonus(4),
			new PlateSetBonus(6),
		};

		public override SetPart[] Parts { get { return m_Parts; } }
		public override SetBonus[] Bonuses { get { return m_Bonuses; } }

		public override int Hue { get { return 0; } }

		public override string Name { get { return "Plate Avenger"; } }
	}

	public class PlateSetBonus : SetBonus
	{
		private int _CountReq;
		public override int CountReq { get { return _CountReq; } }

		public PlateSetBonus(int countReq)
		{ _CountReq = countReq; }

		public override void Apply(Mobile m)
		{
			//Add the stat mod (+10 Str - Infinite Duration)
			m.AddStatMod(new StatMod(StatType.Str, "PlateSetBonus" + _CountReq, 10, TimeSpan.Zero));
		}

		public override void Remove(Mobile m)
		{
			//Check to see if the have the stat mod (+10 Str)
			if (m.GetStatMod("PlateSetBonus" + _CountReq) != null)
			{
				//Remove the stat mod (-10 Str)
				m.RemoveStatMod("PlateSetBonus" + _CountReq);
			}
		}
	}
}